========================
Team and repository tags
========================

.. image:: http://governance.openstack.org/badges/sahara-tests.svg
    :target: http://governance.openstack.org/reference/tags/index.html

.. Change things from this point on

Tests for Sahara project
========================

.. image:: https://img.shields.io/pypi/v/sahara-tests.svg
    :target: https://pypi.python.org/pypi/sahara-tests/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/dm/sahara-tests.svg
    :target: https://pypi.python.org/pypi/sahara-tests/
    :alt: Downloads

In sahara_tests folder we have next tools:
    - Sahara-scenario framework
    - Sahara tempest tests

* License: Apache License, Version 2.0
* `Sahara-scenario documentation`_
* `PyPi`_ - package installation
* `Launchpad project`_ - release management
* `Blueprints`_ - feature specifications
* `Source`_
* `Specs`_
* `Release notes`_

.. _Sahara-scenario documentation: https://docs.openstack.org/sahara-tests/latest/scenario.html
.. _PyPi: https://pypi.python.org/pypi/sahara-tests
.. _Launchpad project: https://launchpad.net/sahara-tests
.. _Blueprints: https://blueprints.launchpad.net/sahara-tests
.. _Source: https://git.openstack.org/cgit/openstack/sahara-tests
.. _Specs: http://specs.openstack.org/openstack/sahara-specs/
.. _Release notes: http://docs.openstack.org/releasenotes/sahara-tests/unreleased.html
